@@ -1,7 +1,9 @@
 package Sah::Schema::unix::local_gid;
 
-our $DATE = '2019-09-11'; # DATE
-our $VERSION = '0.005'; # VERSION
+# AUTHOR
+our $DATE = '2019-11-28'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.006'; # VERSION
 
 our $schema = ["unix::gid" => {
     summary => 'Group identifier (GID) that has to exist on the system',
@@ -13,7 +15,7 @@ returns a record.
 Support coercion from an existing group name.
 
 _
-    'x.perl.coerce_rules' => ['str_convert_unix_group_to_gid', 'int_check_gid_exists'],
+    'x.perl.coerce_rules' => ['From_str::ConvertUnixGroupToGID', 'From_int::CheckGIDExists'],
 }, {}];
 
 1;
@@ -31,7 +33,7 @@ Sah::Schema::unix::local_gid - Group identifier (GID) that has to exist on the s
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-09-11.
+This document describes version 0.006 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
