@@ -1,7 +1,9 @@
 package Sah::Schema::unix::local_uid;
 
-our $DATE = '2019-09-11'; # DATE
-our $VERSION = '0.005'; # VERSION
+# AUTHOR
+our $DATE = '2019-11-28'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.006'; # VERSION
 
 our $schema = ["unix::uid" => {
     summary => 'User identifier (UID) that has to exist (has associated username) on the system',
@@ -13,7 +15,7 @@ returns a record.
 Support coercion from an existing user name.
 
 _
-    'x.perl.coerce_rules' => ['str_convert_unix_user_to_uid', 'int_check_uid_exists'],
+    'x.perl.coerce_rules' => ['From_str::ConvertUnixUserToUID', 'From_int::CheckUIDExists'],
 }, {}];
 
 1;
@@ -31,7 +33,7 @@ Sah::Schema::unix::local_uid - User identifier (UID) that has to exist (has asso
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-09-11.
+This document describes version 0.006 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
